package bz393.controller;

import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.util.List;

import org.slim3.controller.Controller;
import org.slim3.controller.Navigation;
import org.slim3.datastore.Datastore;
import org.slim3.util.RequestMap;
import org.slim3.util.ThrowableUtil;

import bz393.meta.ScoreMeta;
import bz393.model.Score;
import bz393.service.ScoreService;

//サーブレット的な処理をするクラス
//クラス名の【Controller】より前の文字列がURLとなってアクセスすることができる
//ここでは、/AddScore
public class AddScoreController extends Controller {

    private ScoreService service = new ScoreService();
    private ScoreMeta scoreMeta = new ScoreMeta();
   
    @Override
    public Navigation run() throws Exception {
        
        //リクエストのパラメータをMap形式で引数として、ScoreServiceクラスのaddメソッドを実行
        service.add(new RequestMap(request));
        
        //Datastoreに入っているScoreデータをスコアが高い順に取り出し
        List<Score> list = Datastore.query(scoreMeta).sort(scoreMeta.score.desc).asList();
        //List形式をObject[]形式に変換する
        Object[] stArray = (Object[]) list.toArray(new Object[list.size()]);
        //Object[]形式をJson形式の文字列に変換
        String json =  scoreMeta.modelsToJson(stArray);
        
        //文字コードを設定しないと日本語文字化けっぽい
        String encoding = request.getCharacterEncoding();
 
        //json形式の文字列を出力
        try {
            PrintWriter out = null;
            try {
                //文字列の出力処理
                out = new PrintWriter(new OutputStreamWriter(response.getOutputStream(), encoding));
                out.print(json);
                
                //この1行だけだと日本語が化ける
                //response.getWriter().print(json);
            } finally {
                if (out != null) {
                    out.close();
                }
            }
        } catch (IOException e) {
            ThrowableUtil.wrapAndThrow(e);
        }       
        //add.htmlにジャンプ
        return redirect(basePath + "add.html");    
        
        //更新されたjsonを取得
        //return redirect(basePath + "json");
    }
}
