package bz393.controller;

import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.util.List;
import org.slim3.controller.Controller;
import org.slim3.controller.Navigation;
import org.slim3.datastore.Datastore;
import org.slim3.util.ThrowableUtil;

import bz393.meta.ScoreMeta;
import bz393.model.Score;

//サーブレット的な処理をするクラス
//クラス名の【Controller】より前の文字列がURLとなってアクセスすることができる
//ここでは、/Json
public class JsonController extends Controller {

    private ScoreMeta scoreMeta = new ScoreMeta();
    
    @Override
    public Navigation run() throws Exception {

        //Datastoreに入っているScoreデータをスコアが高い順に取り出し
        List<Score> list = Datastore.query(scoreMeta).sort(scoreMeta.score.desc).asList();
        //List形式をObject[]形式に変換する
        Object[] stArray = (Object[]) list.toArray(new Object[list.size()]);
        //Object[]形式をJson形式の文字列に変換
        String json =  scoreMeta.modelsToJson(stArray);
        
        //文字コードを設定しないと日本語文字化けっぽい
        String encoding = request.getCharacterEncoding();
 
        //json形式の文字列を出力
        try {
            PrintWriter out = null;
            try {
                //
                out = new PrintWriter(new OutputStreamWriter(response.getOutputStream(), encoding));
                out.print(json);
                
                //この1行だけだと日本語が化ける
                //response.getWriter().print(json);
            } finally {
                if (out != null) {
                    out.close();
                }
            }
        } catch (IOException e) {
            ThrowableUtil.wrapAndThrow(e);
        }       
    
        return null;
    }
}
